print("hello from mymodule!")

def foo2():
    return "bar2"
